*****************************
This is my first pypi package
*****************************

Steps
=====

 - step 1: " install poetry and open it with vscode"
 - step 2: " "

.. code-block:: c

    #include <stdio.h>
    int main()
    {
    printf("Hello world!")
    return 0
    }
